######################
Changes in glymur 0.13
######################

*****************
Changes in 0.13.8
*****************

    * Fix tiff2jp2 bug when stripped TIFF has no RowsPerStrip tag.

*****************
Changes in 0.13.7
*****************

    * Qualify on python 3.13
    * Fix test warnings due to scikit-image deprecation.
    * Update CI test matrix, tighten 3rd party library requirements.
    * Add ability to construct XML box from file-like object.
    * Add circle-ci CI.
    * Fix test suite for numpy 2.x printing (thanks to Arne Keller).

*****************
Changes in 0.13.6
*****************

    * Fix tiff2jp2 when tile coverage not square.

*****************
Changes in 0.13.5
*****************

    * Add support for parsing the CAP segment.
    * End official support for OpenJPEG 2.3.x.
    * Fix issue preventing API docs from building.

*****************
Changes in 0.13.4
*****************

    * Don't reset openjpeg codec in Jp2k if already set in Jp2kr.
    * Update CI configuration to specify openjpeg versions.

*****************
Changes in 0.13.3
*****************

    * Refactor parsing errors and warnings.
    * Update CI configuration for numpy 2.0.
    * Skip psnr doctest for numpy 2.0.
    * Fix test issue on s390x.
    * Refactor code pattern for finding first element.

*****************
Changes in 0.13.2
*****************

    * Improve doctesting, fix broken libtiff doctest
    * Increase code coverage
    * Remove python 3.8 anachronisms
    * Fix repr for Jp2kr
    * Clean up ci directory
    * Change parsing of precinct sizes due to numpy 2.0, It is now
      represented by a numpy array rather than a list of tuples. This could
      be considered a minor incompatibility, but element-by-element access
      is still the same.

*****************
Changes in 0.13.1
*****************

    * Remove debugging code
    * Improve code coverage

*****************
Changes in 0.13.0
*****************

    * Refactor Jp2k class into Jp2kr (just for reading) and Jp2k (reading and writing).  Backwards compatibility should be maintained.
    * Simplify example file nemo.jp2
    * Fix doctests

